@@ -13,7 +13,7 @@ def arguments_parse():
                                     description="基本用法 python -m make_vcard inputFileName.xlsx outputFileName",
                                     epilog="该程序目前只支持字段：姓名、电话、邮箱、备注",
                                     )
-    parser.add_argument("--example", action="store_true", help="生成示例execl文件；")
+    parser.add_argument("--example", action="store_true", help="生成示例excel文件；")
     parser.add_argument("--sheet", type=str, help="指定读取哪张表；默认为当前表")
     
     parser.add_argument("inputFileName", default="", type=str, help="指定读取的xlsx文件；仅支持xlsx格式文件")
@@ -23,8 +23,8 @@ def arguments_parse():
 
 
 def example():
-    execl = openpyxl.Workbook()
-    sheet = execl.active
+    excel = openpyxl.Workbook()
+    sheet = excel.active
     sheet["A1"] = "姓名"
     sheet["A2"] = "张三"
     sheet["B1"] = "电话"
@@ -33,7 +33,7 @@ def example():
     sheet["C2"] = "备注备注备注备注备注备注备注备注备注备注备注备注"
     sheet["D1"] = "邮箱"
     sheet["D2"] = "123@456.com"
-    execl.save("example.xlsx")
+    excel.save("example.xlsx")
     print("示例文件已成功生成。")
     return 0
 
