@@ -12,10 +12,10 @@ def read_file_xlsx_data(fn):
     global SHEET
     assert os.path.isfile(fn), "文件不存在"
 
-    execl = openpyxl.load_workbook(fn)
-    sheet = execl.active
+    excel = openpyxl.load_workbook(fn)
+    sheet = excel.active
     if SHEET is not None:
-        sheet = execl[SHEET]
+        sheet = excel[SHEET]
 
     i = 1
     ds = {}
@@ -27,15 +27,9 @@ def read_file_xlsx_data(fn):
         ds[value] = i-1
         i += 1
 
-    okds = {}
-    for k in VCARD:
-        if VCARD[k] in ds:
-            okds[VCARD[k]] = ds[VCARD[k]]
+    okds = { VCARD[k] : ds[VCARD[k]] for k in VCARD if VCARD[k] in ds }
 
-    if (VCARD["N"] not in okds) or (VCARD["TEL"] not in okds):
-        print("缺少必要数据\n--help 显示帮助信息")
-        return 1
-    
+    assert (VCARD["N"] in okds) or (VCARD["TEL"] in okds), "缺少必要数据\n--help 显示帮助信息"
     f = 0
     # data = []
     for r in sheet.rows:
